@@ -35,7 +35,7 @@ def test_hard_delete_soft_deleted_task(
     app, service, identity_simple, input_data
 ):
     draft = service.create(identity_simple, input_data)
-    service.publish(draft.id, identity_simple)
+    service.publish(identity_simple, draft.id)
     draft_model = service.draft_cls.model_cls
 
     assert len(draft_model.query.filter(
