@@ -13,7 +13,7 @@
 def create_and_publish(service, identity_simple, input_data):
     """Creates a draft and publishes it."""
     draft = service.create(identity_simple, input_data)
-    record = service.publish(draft.id, identity_simple)
+    record = service.publish(identity_simple, draft.id)
 
     assert record.id == draft.id
     assert record._record.revision_id == 1
